@@ -110,6 +110,11 @@ class NodeFormat:
         """"Add new field if it doesn't exist"""
         if name not in self.fieldNames():
             self.addNewField(name, attrs)
+            if self.genericType:
+                genericType = globalref.docRef.treeFormats.\
+                                        findFormat(self.genericType)
+                if genericType:
+                    genericType.addNewField(name, attrs)
 
     def addLine(self, text):
         """Add format line to end of lineList, line 0 is the title"""
@@ -504,8 +509,12 @@ class FileInfoFormat(NodeFormat):
         item.data[_(FileInfoFormat.dateFieldName)] = repr(GenDate(modTime))
         item.data[_(FileInfoFormat.timeFieldName)] = repr(GenTime(modTime))
         if sys.platform != 'win32':
-            item.data[_(FileInfoFormat.ownerFieldName)] = \
-                               pwd.getpwuid(status[stat.ST_UID])[0]
+            try:
+                item.data[_(FileInfoFormat.ownerFieldName)] = \
+                                   pwd.getpwuid(status[stat.ST_UID])[0]
+            except KeyError:
+                item.data[_(FileInfoFormat.ownerFieldName)] = \
+                                   repr(status[stat.ST_UID])
 
     def getHeaderFooter(self, header=True):
         """Return formatted text for the header or the footer"""
