@@ -98,6 +98,8 @@ class TreeDoc:
         if not hasattr(fileRef, 'read'):
             fileRef = file(fileRef.encode(TreeDoc.localEncoding), 'rb')
             # binary mode req'd for encryption
+        if hasattr(fileRef, 'seek'):
+            fileRef.seek(0)
         prefix = fileRef.read(2)
         self.compressFile = prefix == '\037\213'
         if hasattr(fileRef, 'seek'):
@@ -233,9 +235,10 @@ class TreeDoc:
             textList = f.readlines()
         except UnicodeError:
             print 'Warning - bad unicode characters were replaced'
-            f.close()
             if errors == 'strict':
                 self.readTabbed(fileRef, 'replace')
+            else:
+                f.close()
             return
         f.close()
         bufList = [(text.count('\t', 0, len(text) - len(text.lstrip())), \
@@ -263,9 +266,10 @@ class TreeDoc:
             textList = f.readlines()
         except UnicodeError:
             print 'Warning - bad unicode characters were replaced'
-            f.close()
             if errors == 'strict':
                 self.readTable(fileRef, 'replace')
+            else:
+                f.close()
             return
         f.close()
         treeFormats = TreeFormats([], True)  # set defaults ROOT & DEFAULT
@@ -299,9 +303,10 @@ class TreeDoc:
             textList = f.readlines()
         except UnicodeError:
             print 'Warning - bad unicode characters were replaced'
-            f.close()
             if errors == 'strict':
                 self.readLines(fileRef, 'replace')
+            else:
+                f.close()
             return
         f.close()
         treeFormats = TreeFormats([], True)  # set defaults ROOT & DEFAULT
@@ -329,9 +334,10 @@ class TreeDoc:
             fullText = f.read().replace('\r', '')
         except UnicodeError:
             print 'Warning - bad unicode characters were replaced'
-            f.close()
             if errors == 'strict':
                 self.readPara(fileRef, 'replace')
+            else:
+                f.close()
             return
         textList = fullText.split('\n\n')
         f.close()
@@ -365,9 +371,10 @@ class TreeDoc:
             f.close()
         except UnicodeError:  # error common - broken unicode on windows
             print 'Warning - bad unicode characters were replaced'
-            f.close()
             if errors == 'strict':
                 self.readTreepad(fileRef, 'replace')
+            else:
+                f.close()
             return
         treeFormats = TreeFormats()
         format = NodeFormat(TreeFormats.formatDefault)
@@ -391,9 +398,8 @@ class TreeDoc:
                     lines = lines[2:]
                 except (ValueError, IndexError):
                     print 'Error - bad file format in %s' % \
-                          fileName.encode(TreeDoc.localEncoding)
-                    raise ReadFileError(_('Error - bad file format in %s') % \
-                                        fileName)
+                          filePath.encode(TreeDoc.localEncoding)
+                    raise ReadFileError(_('Bad file format in %s') % filePath)
                 item = TreeItem(None, format)
                 item.data[titleFieldName] = title
                 item.data[TreeFormats.textFieldName] = '\n'.join(lines)
@@ -479,9 +485,10 @@ class TreeDoc:
             fullText = f.read()
         except UnicodeError:
             print 'Warning - bad unicode characters were replaced'
-            f.close()
             if errors == 'strict':
                 self.readMozilla(fileRef, 'replace')
+            else:
+                f.close()
             return
         try:
             handler = HtmlBookmarkHandler(formats.findFormat(TreeDoc.\
