@@ -457,8 +457,7 @@ class TreeView(QListView):
         if globalref.options.boolData('DragTree') and \
            QTextDrag.decode(event, text) and item and item.docItemRef not in \
            globalref.docRef.selection:
-            newItem = globalref.docRef.readXmlString(unicode(text), \
-                                                     event.source() != self)
+            newItem = globalref.docRef.readXmlString(unicode(text), True)
             if newItem:
                 if newItem.data:
                     itemList = [newItem]
